pub struct McpServer { /* private fields */ }Expand description
MCP Server that exposes skills as tools
Implementations
Sourceimpl McpServer
impl McpServer
Sourcepub fn with_manifest(manifest: SkillManifest) -> Result<Self>
pub fn with_manifest(manifest: SkillManifest) -> Result<Self>
Create a new MCP server with a manifest
Sourcepub async fn discover_tools(&self) -> Result<Vec<DiscoveredTool>>
pub async fn discover_tools(&self) -> Result<Vec<DiscoveredTool>>
Discover all available tools from installed skills and manifest
Sourcepub async fn execute_skill_tool(
&self,
skill_name: &str,
instance_name: &str,
tool_name: &str,
args: HashMap<String, Value>,
) -> Result<ExecutionResult>
pub async fn execute_skill_tool( &self, skill_name: &str, instance_name: &str, tool_name: &str, args: HashMap<String, Value>, ) -> Result<ExecutionResult>
Execute a skill tool
Sourcepub async fn list_skills_output(
&self,
filter_skill: Option<&str>,
offset: Option<usize>,
limit: Option<usize>,
) -> String
pub async fn list_skills_output( &self, filter_skill: Option<&str>, offset: Option<usize>, limit: Option<usize>, ) -> String
Get tools for list_skills response with optional pagination
Sourcepub async fn search_skills(&self, query: &str, top_k: usize) -> Result<String>
pub async fn search_skills(&self, query: &str, top_k: usize) -> Result<String>
Search for skills using semantic vector search via SearchPipeline