McpServer

Struct McpServer 

pub struct McpServer { /* private fields */ }
MCP Server that exposes skills as tools

Implementations

Source

impl McpServer

pub fn new() -> Result<Self>

Create a new MCP server

pub fn with_manifest(manifest: SkillManifest) -> Result<Self>

Create a new MCP server with a manifest

pub async fn discover_tools(&self) -> Result<Vec<DiscoveredTool>>

Discover all available tools from installed skills and manifest

pub async fn execute_skill_tool( &self, skill_name: &str, instance_name: &str, tool_name: &str, args: HashMap<String, Value>, ) -> Result<ExecutionResult>

Execute a skill tool

pub async fn list_skills_output( &self, filter_skill: Option<&str>, offset: Option<usize>, limit: Option<usize>, ) -> String

Get tools for list_skills response with optional pagination

pub async fn search_skills(&self, query: &str, top_k: usize) -> Result<String>

Search for skills using semantic vector search via SearchPipeline

pub async fn generate_examples( &self, _skill_name: &str, _tool_name: Option<&str>, _count: usize, ) -> Result<String>

Generate examples - stub when feature is disabled

pub async fn run(self) -> Result<()>

Run the MCP server using stdio transport

pub async fn run_http( host: &str, port: u16, manifest: Option<SkillManifest>, ) -> Result<()>

Run the MCP server using HTTP streaming transport (SSE)